@@ -12,41 +12,41 @@
 !
 module fi_int
 interface
-SUBROUTINE fi(A, doshift, method, eps, maxiter, x0, G, drift, err)
+SUBROUTINE fi(A, doshift, method, eps, maxit, x0, G, drift, err)
 integer,parameter::dp=kind(0.d0)
   REAL(dp), DIMENSION(:,:,:):: a
   REAL(dp), DIMENSION(:,:) :: g, x0
   REAL(dp) :: eps,err,drift
-  integer :: method, maxiter
+  integer :: method, maxit
   logical :: doshift
 end SUBROUTINE fi
 end interface
 
 interface
-SUBROUTINE fi_n(a,x0,eps,maxiter,g,nverbose)
+SUBROUTINE fi_n(a,x0,eps,maxit,g,nverbose)
 integer,parameter::dp=kind(0.d0)
   REAL(dp), DIMENSION(:,:,:):: a
   REAL(dp), DIMENSION(:,:) :: g, x0
   REAL(dp) :: eps
-  integer :: nverbose,maxiter
+  integer :: nverbose,maxit
 end SUBROUTINE fi_n
 end interface
 interface
-SUBROUTINE fi_t(a,x0,eps,maxiter,g,nverbose)
+SUBROUTINE fi_t(a,x0,eps,maxit,g,nverbose)
 integer,parameter::dp=kind(0.d0)
   REAL(dp), DIMENSION(:,:,:):: a
   REAL(dp), DIMENSION(:,:) :: g, x0
   REAL(dp) :: eps
-  integer :: nverbose,maxiter
+  integer :: nverbose,maxit
 end SUBROUTINE fi_t
 end interface
 interface
-SUBROUTINE fi_u(a,x0,eps,maxiter,g,nverbose)
+SUBROUTINE fi_u(a,x0,eps,maxit,g,nverbose)
 integer,parameter::dp=kind(0.d0)
   REAL(dp), DIMENSION(:,:,:):: a
   REAL(dp), DIMENSION(:,:) :: g, x0
   REAL(dp) :: eps
-  integer :: nverbose,maxiter
+  integer :: nverbose,maxit
 end SUBROUTINE fi_u
 end interface
 interface
