@@ -13,12 +13,12 @@
 !
 module is_int
 interface
-SUBROUTINE is(A, method, eps, maxiter, G, drift, err)
+SUBROUTINE is(A, method, eps, maxit, G, drift, err)
 integer,parameter::dp=kind(0.d0)
   REAL(dp), DIMENSION(:,:,:):: a
   REAL(dp), DIMENSION(:,:) :: g
   REAL(dp) :: eps,err,drift
-  integer :: method, maxiter
+  integer :: method, maxit
 end SUBROUTINE is
 end interface
 
