@@ -15,7 +15,7 @@ subroutine qbdpi(Am1, A0, A1, Bm1, B0, B1, R, maxnc, epspi, pi0,pi,pinc)
   use smc_tools
   USE f95_lapack
   use smc_int, only:gth
-  use ponte_f_f, only: debug,verb,timing,finish,wout
+  use ponte_f_f, only: debug,verb,wout
   implicit none
   
   integer :: maxnc,pinc
@@ -176,7 +176,7 @@ subroutine qbdpi(Am1, A0, A1, Bm1, B0, B1, R, maxnc, epspi, pi0,pi,pinc)
    use smc_tools
    USE f95_lapack
    use smc_int, only:gth
-   use ponte_f_f, only: debug,verb,timing,finish,wout
+   use ponte_f_f, only: debug,verb,wout
    implicit none
    
    integer :: maxnc, pinc
@@ -334,7 +334,7 @@ subroutine gm1pi(A, B, B0, Bm1, R, maxnc, epspi, pi0, pi, pinc)
    use smc_tools
    USE f95_lapack
    use smc_int, only:gth
-   use ponte_f_f, only: debug,verb,timing,finish,wout
+   use ponte_f_f, only: debug,verb,wout
    implicit none
    
    integer :: maxnc, pinc
