@@ -33,12 +33,12 @@
 
 module pwcr_interface
   INTERFACE 
-     SUBROUTINE pwcr(a,eps,g,err,itmax,intpmax)
+     SUBROUTINE pwcr(a,eps,g,err,maxit,intpmax)
        IMPLICIT NONE
        REAL(KIND(0.d0)), DIMENSION(:,:,:) :: a
        REAL(KIND(0.d0)), DIMENSION(:,:)   :: g
        REAL(KIND(0.d0))                            :: err, eps
-       integer :: itmax,intpmax
+       integer :: maxit,intpmax
 
      END SUBROUTINE pwcr
   endinterface
@@ -62,12 +62,12 @@ module pwcr_interface
      END SUBROUTINE residual
   endinterface
   INTERFACE 
-     SUBROUTINE spwcr(a,eps,g,err,itmax,intpmax)
+     SUBROUTINE spwcr(a,eps,g,err,maxit,intpmax)
        IMPLICIT NONE
        REAL(KIND(0.d0)), DIMENSION(:,:,:) :: a
        REAL(KIND(0.d0)), DIMENSION(:,:)   :: g
        REAL(KIND(0.d0))                            :: err, eps
-       integer :: itmax,intpmax
+       integer :: maxit,intpmax
      END SUBROUTINE spwcr
   endinterface
   INTERFACE
