@@ -82,13 +82,13 @@
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 
-SUBROUTINE PWCR(a,eps,g,err,itmax,intpmax)
+SUBROUTINE PWCR(a,eps,g,err,maxit,intpmax)
   USE schur_interface
   USE pwcr_interface, ONLY : computeG, residual
   use smc_tools
   use is_int, only: drft_mg1
   use roots
-    use ponte_f_f, only: debug,verb,timing,finish,wout,fdrift
+    use ponte_f_f, only: debug,verb,wout,fdrift
   IMPLICIT NONE
   REAL(dp), DIMENSION(:,:,:):: a
   REAL(dp), DIMENSION(:,:) :: g
@@ -100,7 +100,7 @@ SUBROUTINE PWCR(a,eps,g,err,itmax,intpmax)
   REAL(dp)                            :: stoc, a0norm
   INTEGER                                     :: m, n, nb, j, &
        l, l1, ln, step
-  integer :: itmax,intpmax, intpmaxl
+  integer :: maxit,intpmax, intpmaxl
 
 !  logical ::  ldoshift
 
@@ -109,7 +109,7 @@ SUBROUTINE PWCR(a,eps,g,err,itmax,intpmax)
   !10 FORMAT(1X,"*",\)
 10 FORMAT("*")
   if (debug) write(*,*) "pwcr:  Dimensions A =",size(a,1), size(a,2),size(a,3),& 
-       "  eps=",eps," err=",err," itmax=",itmax," intpmax=",intpmax
+       "  eps=",eps," err=",err," maxit=",maxit," intpmax=",intpmax
   !-------------------------------------
   ! Prepare the input
   !-------------------------------------
@@ -199,7 +199,7 @@ if(debug)  WRITE(*,*)"pwcr: The matrix A is not stochastic"
           write(wout,10)
           call print_it_nolf
        end if
-        if (step==itmax) then
+        if (step==maxit) then
           write(wout,*)"Reached the maximum number of iterations in PWCR"
           call print_it
           exit
@@ -1169,13 +1169,13 @@ SUBROUTINE solvec(cmat, termc)
   end if
 END SUBROUTINE solvec
 
-SUBROUTINE SPWCR(a,eps,g,err,itmax,intpmax)
+SUBROUTINE SPWCR(a,eps,g,err,maxit,intpmax)
   USE schur_interface
   USE pwcr_interface, ONLY : scomputeG, residual
   use smc_tools
   use smc_int
   use roots
-  use ponte_f_f, only: debug,verb,timing,finish,wout,fdrift
+  use ponte_f_f, only: debug,verb,wout,fdrift
   IMPLICIT NONE
   REAL(dp), DIMENSION(:,:,:):: a
   REAL(dp), DIMENSION(:,:) :: g
@@ -1187,13 +1187,13 @@ SUBROUTINE SPWCR(a,eps,g,err,itmax,intpmax)
   REAL(dp)                            :: stoc, a0norm,drift
   INTEGER                                     :: m, n, nb, j, &
        l, l1, ln, step
-  integer :: itmax,intpmax, intpmaxl
+  integer :: maxit,intpmax, intpmaxl
   intpmaxl=256*2**intpmax
 
 !20 FORMAT(1X,"*",\)
 20 FORMAT("*")
 if (debug) write(*,*) "spwcr:  Dimensions A =",size(a,1), size(a,2),size(a,3),&
-"   eps=",eps," err=",err," itmax=",itmax," intpmax=",intpmax
+"   eps=",eps," err=",err," maxit=",maxit," intpmax=",intpmax
 
   !-------------------------------------
   ! Prepare the input
@@ -1296,7 +1296,7 @@ if(debug)  WRITE(*,*)"spwcr: The matrix A is not stochastic"
         write(wout,20)
         call print_it_nolf
      end if
-        if (step==itmax) then
+        if (step==maxit) then
           write(wout,*)"Reached the maximum number of iterations in PWCR"
           call print_it
           exit
