@@ -28,7 +28,7 @@ module smc_int
      end subroutine gth
   end interface
   interface 
-     subroutine crqbd(Am1, A0, A1, G, R, U, doshift, dogth, drift, nerror, niteraz)
+     subroutine crqbd(Am1, A0, A1, G, R, U, doshift, dogth, drift, nerror, maxit)
        integer, parameter :: dp=kind(0.d0)
        real(dp),dimension(:,:),intent(in)  :: Am1, A0, A1
        real(dp),dimension(:,:),intent(out) :: G
@@ -36,18 +36,18 @@ module smc_int
        real(dp),intent(out),optional ::drift
        logical, optional,intent(in) :: doshift, dogth
        integer,optional,intent(in) :: nerror
-       integer, optional,intent(in) :: niteraz
+       integer, optional,intent(in) :: maxit
      end subroutine crqbd
   end interface
   interface 
-     subroutine lrqbd(Am1, A0, A1,  G, R, U, doshift, dogth, drift, nerror, niteraz)
+     subroutine lrqbd(Am1, A0, A1,  G, R, U, doshift, dogth, drift, nerror, maxit)
        integer, parameter :: dp=kind(0.d0)
        real(dp),dimension(:,:),intent(in) :: Am1, A0, A1
        real(dp),dimension(:,:),intent(out),optional :: G, R, U
        real(dp),intent(out),optional :: drift
        logical, optional,intent(in) :: doshift, dogth
        integer,optional,intent(in) :: nerror
-       integer, optional,intent(in) :: niteraz
+       integer, optional,intent(in) :: maxit
      end subroutine lrqbd
   end interface
   interface
