@@ -16,7 +16,7 @@
     ! Am1,A0,A1 are nonnegative and their sum is stochastic
     use smc_int, only: gth
     use smc_tools
-    use ponte_f_f, only: debug,verb,timing,finish,wout
+    use ponte_f_f, only: debug,verb,wout
     implicit none
     ! arguments
     real(dp),intent(in),dimension(:,:) :: am1,a0,a1
@@ -44,7 +44,7 @@
     ! Compute the probability invariant vector p of the stochastic matrix A
     ! by using the gth trick  
     use smc_tools
-    use ponte_f_f, only: debug,verb,timing,finish,wout
+    use ponte_f_f, only: debug,verb,wout
     use f95_lapack, only: la_gesv
     implicit none
     ! arguments
@@ -112,7 +112,7 @@ subroutine bgth(v,a,b)
   ! Input:  A, v and b
   ! Output: b
     use smc_tools
-    use ponte_f_f, only: debug,verb,timing,finish,wout
+    use ponte_f_f, only: debug,verb,wout
     implicit none
     real(dp),intent(in),dimension(:,:) :: a
     real(dp),intent(inout),dimension(:,:) :: b
@@ -164,7 +164,7 @@ subroutine bgth(v,a,b)
     if (allocated(p)) deallocate(p)
   end subroutine bgth
 
-  subroutine crqbd(Am1, A0, A1,  G, R, U, doshift, dogth,  drift, nerror, niteraz)
+  subroutine crqbd(Am1, A0, A1,  G, R, U, doshift, dogth,  drift, nerror, maxit)
 ! compute the minimal solutions of the equations
 !   Am1 + A0 G + A1 G^2   = G
 !   A1  + R A0 + R^2 Am1  = R
@@ -182,7 +182,7 @@ subroutine bgth(v,a,b)
     use smc_tools
     use smc_int, only: drft, bgth
     USE f95_lapack, ONLY: la_getrf, la_getri, la_gesv
-    use ponte_f_f, only: debug,verb,timing,finish,wout,fdrift
+    use ponte_f_f, only: debug,verb,wout,fdrift
     implicit none
     ! arguments
     real(dp),intent(in),dimension(:,:) :: Am1, A0, A1
@@ -191,7 +191,7 @@ subroutine bgth(v,a,b)
     real(dp),intent(out),optional, dimension(:,:) ::  R, U
     real(dp),intent(out),optional ::drift
     integer,optional,intent(in) :: nerror
-    integer, optional,intent(in) :: niteraz
+    integer, optional,intent(in) :: maxit
     ! parameters
     !real(dp),parameter :: eps=epsilon(1.d0)
     !integer, parameter :: nitmax=50  
@@ -214,10 +214,10 @@ subroutine bgth(v,a,b)
        else 
           eps=epsilon(1.d0) * 10.0d0 ** nerror
     endif
-    if ( .not. present(niteraz)) then
+    if ( .not. present(maxit)) then
           nitmax = 50
        else
-          nitmax = niteraz
+          nitmax = maxit
     endif 
     if (debug) write(*,*) "crqbd: eps=",eps," nitmax=",nitmax
 !   from here nitmax and eps are the values of the parameters
@@ -413,7 +413,7 @@ if(debug) write(*,*) "crqbd: info=",info
 
 
 
-  subroutine lrqbd(Am1, A0, A1, G, R, U, doshift, dogth, drift, nerror, niteraz)
+  subroutine lrqbd(Am1, A0, A1, G, R, U, doshift, dogth, drift, nerror, maxit)
 ! compute the minimal solutions of the equations
 !   Am1 + A0 G + A1 G^2   = G
 !   A1  + R A0 + R^2 Am1  = R
@@ -430,7 +430,7 @@ if(debug) write(*,*) "crqbd: info=",info
     use smc_tools
     use smc_int, only: drft, bgth
     USE f95_lapack, ONLY: la_getrf, la_getri, la_gesv
-    use ponte_f_f, only: debug,verb,timing,finish,wout,fdrift
+    use ponte_f_f, only: debug,verb,wout,fdrift
     implicit none
     ! arguments
     real(dp),dimension(:,:),intent(in) :: Am1, A0, A1
@@ -438,7 +438,7 @@ if(debug) write(*,*) "crqbd: info=",info
     real(dp),intent(out),optional ::drift
     logical, optional,intent(in) :: doshift, dogth
     integer,optional,intent(in) :: nerror
-    integer, optional,intent(in) :: niteraz
+    integer, optional,intent(in) :: maxit
     ! parameters
     !real(dp),parameter :: eps=epsilon(1.d0)
     !integer, parameter :: nitmax=50  
@@ -462,10 +462,10 @@ if(debug) write(*,*) "crqbd: info=",info
        else 
           eps=epsilon(1.d0) * 10.0d0 ** nerror
     endif
-    if ( .not. present(niteraz)) then
+    if ( .not. present(maxit)) then
           nitmax = 50
        else
-          nitmax = niteraz
+          nitmax = maxit
     endif
    if (debug) write(*,*) "lrqbd: eps=",eps," nitmax=",nitmax
 !   from here nitmax and eps are the values of the parameters
@@ -741,7 +741,7 @@ end SUBROUTINE shift
 subroutine gm1tomg1(A, AA, v)
   use smc_tools
   use smc_int, only: gth
-  use ponte_f_f, only: debug,verb,timing,finish,wout
+  use ponte_f_f, only: debug,verb,wout
 
   implicit none
   real(dp),dimension(:,:,:):: A,AA
@@ -776,7 +776,7 @@ end subroutine gm1tomg1
 
 subroutine rresidual(A,r,norm1)
   use smc_tools
-!  use ponte_f_f, only: debug,verb,timing,finish,wout
+!  use ponte_f_f, only: debug,verb,wout
 
   implicit none
   real(dp),dimension(:,:,:):: A
@@ -869,3 +869,17 @@ call la_getrf(aux,ipiv)
 call la_getri(aux,ipiv)
 res=  maxval(abs(u-matmul(a1,matmul(aux,am1))-a0))
 end subroutine qbdures
+
+function binomial(n,k)
+  implicit none
+  integer ::  n,k , i
+  real(kind(0.d0)):: rn,rk,rb,binomial
+  rb=1.d0
+  rn=n
+  rk=k
+  do i=0,k-1
+     rb=((rn-i)/(rk-i))*rb
+  end do
+  binomial=rb
+end function binomial
+
