@@ -521,16 +521,3 @@ write(*,*) "examples_setup: exiting with num=",num," m=",m," n=",n," qa=",qa," q
 end if
 end subroutine  examples_setup
 
-function binomial(n,k)
-  implicit none
-  integer ::  n,k , i
-  real(kind(0.d0)):: rn,rk,rb,binomial
-  rb=1.d0
-  rn=n
-  rk=k
-  do i=0,k-1
-     rb=((rn-i)/(rk-i))*rb
-  end do
-  binomial=rb
-end function binomial
-
