@@ -28,8 +28,6 @@ use smc_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        prototypes in smc_int
@@ -99,7 +97,7 @@ case (1) ! G only
      return
      endif
      call crqbd(am1=A(:,:,1),a0=A(:,:,2),a1=A(:,:,3),G=G,doshift=ds,&
-dogth=dg,drift=drift, nerror=errmax ,niteraz=itermax)
+dogth=dg,drift=drift, nerror=errmax ,maxit=itermax)
      write(wout,*)"drift=",drift
      call print_it
      if (info /= 0 ) then
@@ -124,7 +122,7 @@ case (2) ! G and R
      return
      endif
      call crqbd(am1=A(:,:,1),a0=A(:,:,2),a1=A(:,:,3),G=G,R=R,doshift=ds,&
-dogth=dg,drift=drift, nerror=errmax ,niteraz=itermax)
+dogth=dg,drift=drift, nerror=errmax ,maxit=itermax)
      write(wout,*)"drift=",drift
      call print_it
      if (info /= 0 ) then
@@ -155,7 +153,7 @@ case (3) ! G R and U
      return
      endif
      call crqbd(am1=A(:,:,1),a0=A(:,:,2),a1=A(:,:,3),G=G,R=R,U=U,doshift=ds,&
-dogth=dg,drift=drift, nerror=errmax ,niteraz=itermax)
+dogth=dg,drift=drift, nerror=errmax ,maxit=itermax)
      write(wout,*)"drift=",drift
      call print_it
      if (info /= 0 ) then
@@ -186,7 +184,7 @@ case (4) ! G R U and Pi
      return
      endif
      call crqbd(am1=A(:,:,1),a0=A(:,:,2),a1=A(:,:,3),G=G,R=R,U=U,doshift=ds,&
-dogth=dg,drift=drift, nerror=errmax ,niteraz=itermax)
+dogth=dg,drift=drift, nerror=errmax ,maxit=itermax)
      write(wout,*)"drift=",drift
      call print_it
       if (info /= 0 ) then
@@ -242,8 +240,6 @@ use smc_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail
 ! character (len=256) wout  !line of output
 !
 !        prototypes in smc_int
@@ -310,7 +306,7 @@ case (1) ! G only
      return
      endif
      call lrqbd(am1=A(:,:,1),a0=A(:,:,2),a1=A(:,:,3),G=G,doshift=ds,&
-dogth=dg,drift=drift, nerror=errmax ,niteraz=itermax)
+dogth=dg,drift=drift, nerror=errmax ,maxit=itermax)
      write(wout,*)"drift=",drift
      call print_it
       if (debug) write (*,*) "qbd_lr_solve:  Logarithmic Reduction  did find G"
@@ -330,7 +326,7 @@ case (2) ! G and R
      return
      endif
      call lrqbd(am1=A(:,:,1),a0=A(:,:,2),a1=A(:,:,3),G=G,R=R,doshift=ds,&
-dogth=dg,drift=drift, nerror=errmax ,niteraz=itermax)
+dogth=dg,drift=drift, nerror=errmax ,maxit=itermax)
      write(wout,*)"drift=",drift
      call print_it
       if (debug) write (*,*) "qbd_lr_solve:  Logarithmic Reduction  did find G and R"
@@ -356,7 +352,7 @@ case (3) ! G R and U
      return
      endif
      call lrqbd(am1=A(:,:,1),a0=A(:,:,2),a1=A(:,:,3),G=G,R=R,U=U,doshift=ds,&
-dogth=dg,drift=drift, nerror=errmax ,niteraz=itermax)
+dogth=dg,drift=drift, nerror=errmax ,maxit=itermax)
      write(wout,*)"drift=",drift
      call print_it
       if (debug) write (*,*) "qbd_lr_solve:  Logarithmic Reduction  did find G, R and U"
@@ -382,7 +378,7 @@ case (4) ! G R U and Pi
      return
      endif
      call lrqbd(am1=A(:,:,1),a0=A(:,:,2),a1=A(:,:,3),G=G,R=R,U=U,doshift=ds,&
-dogth=dg,drift=drift, nerror=errmax ,niteraz=itermax)
+dogth=dg,drift=drift, nerror=errmax ,maxit=itermax)
      write(wout,*)"drift=",drift
      call print_it
       if (debug) write (*,*) "qbd_lr_solve:  Logarithmic Reduction  did find G, R and U"
@@ -421,8 +417,6 @@ use smc_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
@@ -600,7 +594,7 @@ end select
 !
 ! setup goals
 !
-call fi(A=A, doshift=ds, method=method, eps=myeps, maxiter=itermax, x0=X0, G=G, drift=drift, err=norm1)
+call fi(A=A, doshift=ds, method=method, eps=myeps, maxit=itermax, x0=X0, G=G, drift=drift, err=norm1)
 if ( .not. verb) then
    write(wout,*)" "
    call print_it
@@ -675,15 +669,13 @@ use smc_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
 ! integer,parameter :: dp=kind(0.d0)
 ! integer :: info=0 info /=0 will catch allocation errors
 !
-!        globals inpwcr_interface
+!        globals in pwcr_interface
 ! subroutine pwcr(a,eps,g,err)  
 ! 
 implicit none
@@ -722,13 +714,13 @@ m=size(A,1)
      endif
 
 !!
-!call is(A, method=algflag, eps=myeps, maxiter=itermax, G=G, drift=drift, err=norm1);
+!call is(A, method=algflag, eps=myeps, maxit=itermax, G=G, drift=drift, err=norm1);
 !!write(wout,*)"********** algorithm not ready ********** work in progress **********"
 !!call print_it
 !!
 
 !!
-call is(A, method=algflag, eps=myeps, maxiter=itermax, G=G, drift=drift, err=norm1);
+call is(A, method=algflag, eps=myeps, maxit=itermax, G=G, drift=drift, err=norm1);
 !!write(wout,*)"********** algorithm not ready ********** work in progress **********"
 !!call print_it
 !!
@@ -807,15 +799,13 @@ use pwcr_interface
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
 ! integer,parameter :: dp=kind(0.d0)
 ! integer :: info=0 info /=0 will catch allocation errors
 !
-!        globals inpwcr_interface
+!        globals in pwcr_interface
 ! subroutine pwcr(a,eps,g,err)  
 ! 
 implicit none
@@ -858,9 +848,9 @@ case (1) ! G only
      errorflag=info
      return
      endif
-     if (algflag==0) call  pwcr(A=A,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax)
-     if (algflag==1) call  spwcr(A=A,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax) 
-     if (algflag==2) call  pwcr(A=A,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax) 
+     if (algflag==0) call  pwcr(A=A,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax)
+     if (algflag==1) call  spwcr(A=A,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax) 
+     if (algflag==2) call  pwcr(A=A,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax) 
      if (info /= 0 ) then
        errorflag=info
         if (info == 500) then
@@ -890,9 +880,9 @@ case (2) ! G and Pi
      errorflag=info
      return
      endif
-     if (algflag==0) call  pwcr(A=A,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax) 
-     if (algflag==1) call  spwcr(A=A,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax)
-     if (algflag==2) call  pwcr(A=A,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax)
+     if (algflag==0) call  pwcr(A=A,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax) 
+     if (algflag==1) call  spwcr(A=A,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax)
+     if (algflag==2) call  pwcr(A=A,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax)
      if (info /= 0 ) then
        errorflag=info
         if (info == 500) then
@@ -961,8 +951,6 @@ use fi_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
@@ -1139,7 +1127,7 @@ end select
 ! setup goals
 ! only G for now
 !
-call fi(A=A, doshift=ds, method=method, eps=myeps, maxiter=itermax, x0=X0, G=G, drift=drift, err=norm1)
+call fi(A=A, doshift=ds, method=method, eps=myeps, maxit=itermax, x0=X0, G=G, drift=drift, err=norm1)
 if ( .not. verb) then
        write(wout,*)" "
        call print_it
@@ -1172,8 +1160,6 @@ use is_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
@@ -1218,7 +1204,7 @@ m=size(A,1)
      return
      endif
 
-call is(A, method=algflag, eps=myeps, maxiter=itermax, G=G, drift=drift, err=norm1)
+call is(A, method=algflag, eps=myeps, maxit=itermax, G=G, drift=drift, err=norm1)
 write(wout,*)"G-residual=",norm1
 call print_it
 write(wout,*)"drift=",drift
@@ -1252,8 +1238,6 @@ use smc_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
@@ -1323,9 +1307,9 @@ case (1) ! G only
      errorflag=info
      return
      endif
-     if (algflag==0) call  pwcr(A=AA,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax)
-     if (algflag==1) call  spwcr(A=AA,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax) 
-     if (algflag==2) call  pwcr(A=AA,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax) 
+     if (algflag==0) call  pwcr(A=AA,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax)
+     if (algflag==1) call  spwcr(A=AA,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax) 
+     if (algflag==2) call  pwcr(A=AA,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax) 
      if (info /= 0 ) then
        errorflag=info
         if (info == 500) then
@@ -1366,9 +1350,9 @@ case (2) ! G and Pi
      errorflag=info
      return
      endif
-     if (algflag==0) call  pwcr(A=AA,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax) 
-     if (algflag==1) call  spwcr(A=AA,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax)
-     if (algflag==2) call  pwcr(A=AA,eps=myeps,G=G,err=norm1,itmax=itermax,intpmax=interpmax)
+     if (algflag==0) call  pwcr(A=AA,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax) 
+     if (algflag==1) call  spwcr(A=AA,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax)
+     if (algflag==2) call  pwcr(A=AA,eps=myeps,G=G,err=norm1,maxit=itermax,intpmax=interpmax)
      if (info /= 0 ) then
        errorflag=info
         if (info == 500) then
@@ -1480,8 +1464,6 @@ use smc_tools
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
@@ -1542,8 +1524,6 @@ use fi_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
@@ -1751,7 +1731,7 @@ end select
 call gm1tomg1(A,AA,v)
 
 
-call fi(A=AA, doshift=ds, method=method, eps=myeps, maxiter=itermax,&
+call fi(A=AA, doshift=ds, method=method, eps=myeps, maxit=itermax,&
  x0=X0, G=G, drift=drift, err=norm1)
        r=transpose(g)
      if (allocated(vi)) deallocate(vi)
@@ -1802,8 +1782,6 @@ use is_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out 
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
@@ -1875,7 +1853,7 @@ endif
 
 call gm1tomg1(A,AA,v)
 
-call is(A=AA, method=algflag, eps=myeps, maxiter=itermax, G=G, drift=drift, err=norm1)
+call is(A=AA, method=algflag, eps=myeps, maxit=itermax, G=G, drift=drift, err=norm1)
 !!
 r=transpose(g)
      if (allocated(vi)) deallocate(vi)
@@ -1923,8 +1901,6 @@ use pi_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
@@ -1998,8 +1974,6 @@ use pi_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
@@ -2074,8 +2048,6 @@ use pi_int
 ! real(KIND=8),dimension(:,:),allocatable:: Pi0
 ! logical debug  !if true debugging output to std out
 ! logical verb   !if true more detailed output to NotePad
-! logical timing !if true calculations partial times are computed
-! logical finish !true if calculation did not fail *** duplicate info and errorflag behavior ??? unused ???
 ! character (len=256) wout  !line of output
 !
 !        globals in smc_tools
