@@ -3,6 +3,11 @@
 !  -- LAPACK95 interface driver routine (version 3.0) --
 !     UNI-C, Denmark; Univ. of Tennessee, USA; NAG Ltd., UK
 !     September, 2000
+!
+
+!
+! -- N.B.     This is not the original version !
+!    only the routines called by SMCSolver_1.2 are present here
 !
 
      INTERFACE LA_GESVD
@@ -292,6 +297,31 @@
       END INTERFACE
 
 
+      INTERFACE LA_ORGQR
+
+      SUBROUTINE DORGQR( M, N, K, A, LDA, TAU, WORK, LWORK, INFO )
+         USE LA_PRECISION, ONLY: WP => DP
+         INTEGER, INTENT(IN) :: K, LDA, LWORK, M, N
+         INTEGER, INTENT(OUT) :: INFO
+         REAL(WP), INTENT(INOUT) :: A(LDA,*)
+         REAL(WP), INTENT(IN) :: TAU(*)
+         REAL(WP), INTENT(OUT) :: WORK(LWORK)
+      END SUBROUTINE DORGQR
+      END INTERFACE
+
+      INTERFACE LA_GEQP3
+
+      SUBROUTINE DGEQP3( M, N, A, LDA, JPVT, TAU, WORK, LWORK,       &
+     &                      INFO )
+      USE LA_PRECISION, ONLY: WP => DP
+      INTEGER, INTENT(IN) :: LDA, LWORK, M, N
+      INTEGER, INTENT(OUT) :: INFO
+      INTEGER, INTENT(INOUT) :: JPVT( * )
+      REAL(WP), INTENT(INOUT) :: A( LDA, * )
+      REAL(WP), INTENT(OUT) :: TAU( * ), WORK(LWORK)
+      END SUBROUTINE DGEQP3
+      END INTERFACE
+
 
       CONTAINS
 
