@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.1 - Oct 2006                                     *
+ * Version 1.2 - Nov 2006                                     *
  **************************************************************
  *
  *  rw.h - reading and writing files
@@ -16,29 +16,34 @@
 /* prototypes rw.c */
 void on_ok_button_fs1_clicked      (GtkButton   *, gpointer );
 void on_cancel_button_fs1_clicked  (GtkButton   *, gpointer );
+void on_destroy_fs1 ( GtkWidget  *, gpointer );
 
 void on_ok1_button_fsg_clicked      (GtkButton   *, gpointer  );
 void on_ok2_button_fsg_clicked      (GtkButton   *, gpointer  );
 void on_ok3_button_fsg_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fsg_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fsg ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_g(void);
 
 void on_ok1_button_fsr_clicked      (GtkButton   *, gpointer  );
 void on_ok2_button_fsr_clicked      (GtkButton   *, gpointer  );
 void on_ok3_button_fsr_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fsr_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fsr ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_r(void);
 
 void on_ok1_button_fsu_clicked      (GtkButton   *, gpointer  );
 void on_ok2_button_fsu_clicked      (GtkButton   *, gpointer  );
 void on_ok3_button_fsu_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fsu_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fsu ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_u(void);
 
 void on_ok1_button_fsgru_clicked      (GtkButton   *, gpointer  );
 void on_ok2_button_fsgru_clicked      (GtkButton   *, gpointer  );
 void on_ok3_button_fsgru_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fsgru_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fsgru ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_gru(void);
 
 void on_ok1_button_fssavea_clicked      (GtkButton   *, gpointer  );
@@ -47,6 +52,7 @@ void on_ok3_button_fssavea_clicked      (GtkButton   *, gpointer  );
 void on_ok4_button_fssavea_clicked      (GtkButton   *, gpointer  );
 void on_ok5_button_fssavea_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fssavea_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fssavea ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_savea(void);
 
 void on_ok1_button_fssaveb_clicked      (GtkButton   *, gpointer  );
@@ -56,6 +62,7 @@ void on_ok4_button_fssaveb_clicked      (GtkButton   *, gpointer  );
 void on_ok5_button_fssaveb_clicked      (GtkButton   *, gpointer  );
 void on_ok6_button_fssaveb_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fssaveb_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fssaveb ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_saveb(void);
 
 void on_ok1_button_fssavepi_clicked      (GtkButton   *, gpointer  );
@@ -65,22 +72,26 @@ void on_ok4_button_fssavepi_clicked      (GtkButton   *, gpointer  );
 void on_ok5_button_fssavepi_clicked      (GtkButton   *, gpointer  );
 void on_ok6_button_fssavepi_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fssavepi_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fssavepi ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_pi(void);
 
 void on_ok1_button_fsreada_clicked      (GtkButton   *, gpointer  );
 void on_ok2_button_fsreada_clicked      (GtkButton   *, gpointer  );
 void on_ok3_button_fsreada_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fsreada_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fsreada ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_reada(void);
 
 void on_ok1_button_fsreadb_clicked      (GtkButton   *, gpointer  );
 void on_ok2_button_fsreadb_clicked      (GtkButton   *, gpointer  );
 void on_ok3_button_fsreadb_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fsreadb_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fsreadb ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_readb(void);
 
 void on_ok_button_fsX_clicked      (GtkButton   *, gpointer  );
 void on_cancel_button_fsX_clicked      (GtkButton   *, gpointer  );
+void on_destroy_fsX ( GtkWidget  *, gpointer );
 GtkWidget* create_fileselection_X(void);
 
 
@@ -116,6 +127,7 @@ gint selection_uptodaten(void);
 
 /* prototypes callback.c */
 void invalidate_completed(void);
+gboolean on_delete_event_do   (GtkWidget *, GdkEvent *, gpointer);
 
 /* prototypes ponte.f90 */
 /* note: Fortran exports names in lower case only, so read_matA becomes read_mata_  ... */
